Name
That doesn't look like a valid instance name.
Too long instance name.
Flavor {$ flavor.name $}
You must supply a flavor.
Boot from source {$ source.name $} Image {$ image.name $} Image Snapshot {$ iss.name $} Volume {$ vol.name $} Volume Snapshot {$ volss.name $} Availability Zone {$ az.name $} {$ 'Show More Properties' | translate $} Key Name {$ kname.name $} Security Groups {$ sg.name $} Use block_device_mapping_v2
Block Device Mapping v2
Device Name Boot Index Disk Type {$ dtype.name $} Disk Bus {$ diskbus.name $}
Ephemeral Format {$ eformat.name $} Ephemeral Size (G) Swap Size (M) Delete On Termination
Source {$ source.name $}
Image {$ image.name $} Volume {$ vol.name $} Volume Size (G) Snapshot {$ volss.name $}
Network
Allocate Network {$ alloc_net.name $} Specify Property network subnet port floating_ip
Network ID {$ nw.name $} Subnet {$ subnet.name $} Port {$ port.name $} Floating IP {$ fip.id $}
Fixed IP Address
Please input a valid IP address.
Tag
Admin Password Show Password
Flavor Update Policy {$ fup.name $} (Default) Image Update Policy {$ iup.name $} (Default) Reservation ID
That doesn't look like a valid uuid.
Scheduler Hints
Key Value
Config Drive Disk Config {$ dc.name $} (Default) User Data Format {$ udf.name $} (Default) Software Config Transport {$ sct.name $} (Default) User Data Update Policy {$ udup.name $} (Default) User Data
Deployment Swift Data
Container Object
Tags Metadata
Key Value
Personality
Filename Content